clear all

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
training.type=2;  % 0- binary RTRBM, 1- Gaussian RTRBM, 2- Spike and Slab RTRBM
training.nCD=1;  % number of contrastive-divergence iterations
tmp=load('data/MOCAP/subject35_normalized_MOCAP_data.mat');
training.num_of_nodes=length(tmp.dims);  % number of nodes in the graph
training.NVisible=tmp.dims(:);   % a vector wth the number of observations in each node
training.NHidden=training.NVisible*10;   % a vector with the number of hidden units in each node
training.number_of_iterations=10000*(length(tmp.Data)-2);

training.learning_rate=0.001;
training.momentum=0.9;
training.l1_Theta_reg=0.01;   % SRTRBM regularization
training.flag_learn_mask=1;    % 0- don't learn mask, 1- learn mask
training.flag_causal=0;        % 0- learn undirected graph, 1- learn directed graph
training.flag_share_lambda_parm=0; % 0- a single ssRBM lambda parameter for all groups, 1- share the ssRBM parameter lambda only within each group
training.alpha_parm=1.0;       % alpha parameter for ssRBM
training.lambda_parm_init=10.5; % initialization for lambda for ssRBM
training.delta_parm=8.0; % delta hyper-parameter for the SRTRBM step-function
training.kappa=-3; % kappa hyper-parameter for the SRTRBM step-function
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
training.data_file='data/MOCAP/normalized_MOCAP_set1.dat';
training.parameters_file='results/MOCAP_SRTRBM_parameters.dat';

tmp=0;
if ~(exist(training.parameters_file)==2)
    save(training.parameters_file,'tmp');
end
if (exist(training.data_file)==2) && (exist(training.parameters_file)==2)
    [vct]=create_training_file(training);
    parms=[];
    for i=1:length(vct)
        parms=[parms,num2str(vct(i))];
        parms=[parms,' '];
    end
    parms=[parms,training.data_file,' ',training.parameters_file];
    system(['./train_RTRBM_cuda ',parms]);
else
    disp('The data file does not exist, or that there is an issue with the provided parameters file name');
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
testing=training;
testing.data_file='data/MOCAP/normalized_MOCAP_set2.dat';
testing.parameters_file=training.parameters_file;
testing.nCD=1;
testing.number_of_iterations=200; % use 0 in order to average the results over all the testing sequences, otherwise every testing sequence is averaged using testing.number_of_iterations trials
if (exist(testing.data_file)==2) && (exist(testing.parameters_file)==2)
    [vct]=create_training_file(testing);
    parms=[];
    for i=1:length(vct)
        parms=[parms,num2str(vct(i))];
        parms=[parms,' '];
    end
    parms=[parms,testing.data_file,' ',testing.parameters_file];
    system(['./test_RTRBM_cuda ',parms]);
else
    disp('The data or parameters file does not exist');
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
if (testing.type==0 || testing.type==1)
    if testing.flag_learn_mask==1
        [W,Wprime,b,binit,c,Mask]=readParms_RTRBM(testing.parameters_file);
    else
        [W,Wprime,b,binit,c]=readParms_RTRBM(testing.parameters_file);
    end
else
    if testing.flag_learn_mask==1
        [W,Wprime,b,binit,phi,mu,Mask]=readParms_ssRTRBM(testing.parameters_file);
        save results/MOCAP/MOCAP_MASK.mat Mask
    else
        [W,Wprime,b,binit,phi,mu]=readParms_ssRTRBM(testing.parameters_file);
    end
end
if testing.flag_learn_mask==1
    imshow(Mask,[0,1]);
end
